#!/usr/bin/env python
# -*- coding: utf8 -*-

# Script pondu par Olivier Baudu du Labomedia afin de pouvoir écouter en temps réel 
# les modifications effectuées sur l'interface en ligne : http://grilledelamour.labomedia.org/image/
# Pour ce faire, il ecoute le canal #IRC-Sounds-from-Labomedia du serveur irc.freenode.net
# Il le joue ensuite avec FluidSynth via ALSA avec la SoundFont FluidR3_GM.sf2
#
# Publié sous license GPL v3.0
#
# Pour indormation, Olivier n'est pas un développeur. Il écrit ses scripts empiriquement.
# S'ils fonctionnent, ils ne sont pas pour autant à prendre comme modèle.
#
# Pour l'utiliser taper la ligne ci-dessous dans une console après avoir remplacé les *** par un login :
# python CRI-d-IRC.py ***
#
# Attention, si le login est déjà utilisé sur irc.freenode.net il n'y aura pas de message d'erreur, mais la connexion ne se fera pas.


import sys

########################
### IRC

import irclib #http://python-irclib.sourceforge.net/
import ircbot #vient avec irclib

########################
### AUDIO

import fluidsynth #http://code.google.com/p/pyfluidsynth/ a besoin de #http://sourceforge.net/apps/trac/fluidsynth/
import time
import threading

fs = fluidsynth.Synth()
fs.start(driver='alsa')

sfid = fs.sfload("/usr/share/sounds/sf2/FluidR3_GM.sf2") 

fs.program_select(1, sfid, 0, 14)
fs.program_select(2, sfid, 0, 13)
fs.program_select(3, sfid, 0, 36)
fs.program_select(4, sfid, 0, 0)
fs.program_select(5, sfid, 0, 38)
fs.program_select(6, sfid, 0, 21)
fs.program_select(7, sfid, 0, 123)
fs.program_select(8, sfid, 0, 71)

###################################


def playN(note, duree, chan):
    
    fs.noteon(chan, note, 127)
    time.sleep(duree)
    fs.noteoff(chan, note)

class BotModeration(ircbot.SingleServerIRCBot):

    def __init__(self):
        
        # paramètres de connexion IRC
        global nick
        ircbot.SingleServerIRCBot.__init__(self, [("irc.freenode.net", 6667)], nick, "Bot qui écoute le flux pour le traduire en MIDI")
        print ("Connexion à l'IRC en cours...")
        print ("Login: "+sys.argv[1]+".")

    def on_welcome(self, serv, ev):
        
        # connexion au canal IRC
        serv.join("#IRC-Sounds-from-Labomedia")
        time.sleep(5)
        print ("La connexion semble OK.")

    def on_pubmsg(self, serv, ev):
        
        message = ev.arguments()[0] # récupère les nouveaux messages
        message = message.rstrip().rsplit(" ")
        
        if ev.source()[:13] == "Grille2lAmour":

            if len(message) == 5:

                if message[0] == "play":
                    
                    if 0 < int(message[1]) < 128:

                        note = int(message[1])
                        duree = 1
                        chan = int(message[2])+1   
                        thread=threading.Thread(target=playN, args=(note, duree, chan)).start()

if __name__ == "__main__":

    try:

        nick = sys.argv[1]

    except  IndexError:

        print ("Il faut me renseigner un nom en argument...\n...pour que je puisse vous connecter à l'IRC.")
        quit()
        
    else:
    
        if nick[0].isdigit(): 
        
            print ("Désolé, le nom ne doit pas commencer par un chiffre...")
            quit()
        
        else:        

            BotModeration().start()

    

